@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2011 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2015 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: zend_modules.h 306939 2011-01-01 02:19:59Z felipe $ */
+/* $Id$ */
 
 #ifndef MODULES_H
 #define MODULES_H
@@ -33,7 +33,7 @@
 #define ZEND_MODULE_INFO_FUNC_ARGS zend_module_entry *zend_module TSRMLS_DC
 #define ZEND_MODULE_INFO_FUNC_ARGS_PASSTHRU zend_module TSRMLS_CC
 
-#define ZEND_MODULE_API_NO 20090626
+#define ZEND_MODULE_API_NO 20121212
 #ifdef ZTS
 #define USING_ZTS 1
 #else
@@ -98,7 +98,7 @@ struct _zend_module_entry {
 	unsigned char type;
 	void *handle;
 	int module_number;
-	char *build_id;
+	const char *build_id;
 };
 
 #define MODULE_DEP_REQUIRED		1
@@ -113,6 +113,8 @@ struct _zend_module_entry {
 #define ZEND_MOD_CONFLICTS(name)	ZEND_MOD_CONFLICTS_EX(name, NULL, NULL)
 #define ZEND_MOD_OPTIONAL(name)		ZEND_MOD_OPTIONAL_EX(name, NULL, NULL)
 
+#define ZEND_MOD_END { NULL, NULL, NULL, 0 }
+
 struct _zend_module_dep {
 	const char *name;		/* module name */
 	const char *rel;		/* version relationship: NULL (exists), lt|le|eq|ge|gt (to given version) */
